Learn R Programming

acroname (version 0.1.0)

find_articles: Helper to find articles

Description

This function will check if an input word is an article in the English language ('a', 'an', 'the').

Usage

find_articles(word)

Arguments

word

Character vector of length 1 with word to check

Value

Logical vector of length one, TRUE if the word is an article and FALSE if not.

Examples

Run this code
# NOT RUN {
find_articles("the")
find_articles("then")
find_articles("whatever")

# }

Run the code above in your browser using DataLab