powered by
This function will check if an input word is an article in the English language ('a', 'an', 'the').
find_articles(word)
Character vector of length 1 with word to check
Logical vector of length one, TRUE if the word is an article and FALSE if not.
TRUE
FALSE
# NOT RUN { find_articles("the") find_articles("then") find_articles("whatever") # }
Run the code above in your browser using DataLab